package com.sw.patroleditor.component.robot.ctrl;


import com.sw.patroleditor.common.enumData.RobotTypeEnum;
import com.sw.patroleditor.component.robot.message.Move;

import java.net.ConnectException;

public class CtrlInterface implements SWInterface {


    private static volatile CtrlInterface globalInterface;

    private static String url;

    private static int ROBOT_TYPE = RobotTypeEnum.SW_ROBOT.getType(); //1:SW


    //private 私有，禁止直接new()
    private CtrlInterface() {
    }

    //连接方式一 ，默认选择赛为机器人作为接口对象
    public static CtrlInterface connection(String host, int port) {

        url = "http://" + host + ":" + port;

        synchronized (url) {
            globalInterface = new CtrlInterface();
            return globalInterface;
        }
    }

    //连接方式二 ， 指定机器人类型作为接口对象
    public static CtrlInterface connection(String host, int port, int type) {
        ROBOT_TYPE = type;
        return connection(host, port);
    }

    /**
     * 特殊控制指令，关机、重启、急停、一键返回，前置充电等
     *
     * @return String
     * @throws ConnectException
     */
    public String specialtrl(String command) throws ConnectException {
        return globalInterface.specialtrl_SW(url, command);
    }

    /**
     * 机器人移动
     *
     * @param mo 移动类
     * @return String
     * @throws ConnectException
     */
    public String robotCtrl(Move mo) throws ConnectException {
        return globalInterface.robotCtrl_SW(url, mo);
    }

    /**
     * 打开补光灯
     *
     * @param openStatus true/false
     * @return String
     * @throws ConnectException
     */
    public String openLight(boolean openStatus) throws ConnectException {
        return globalInterface.openLight_SW(url, openStatus);
    }

    /**
     * 打开雨刷
     *
     * @param openStatus true/false
     * @return String
     * @throws ConnectException
     */
    public String openWiper(boolean openStatus) throws ConnectException {
        return globalInterface.openWiper_SW(url, openStatus);
    }

    /**
     * 打开避障雷达
     *
     * @param openStatus true/false
     * @return String
     * @throws ConnectException
     */
    public String openRadar(boolean openStatus) throws ConnectException {
        return globalInterface.openRadar_SW(url, openStatus);
    }

    /**
     * 机器人模式切换
     *
     * @param modeType 3：自动巡检模式，4：手动模式
     * @return String
     * @throws ConnectException
     */
    public String modeChange(int modeType) throws ConnectException {
        return globalInterface.modeChange_SW(url, modeType);
    }
}
