package com.sw.patroleditor.component.robot.ctrl;

import com.sw.patroleditor.component.robot.message.Move;
import com.sw.patroleditor.component.robot.message.RobotCtrl;
import com.sw.patroleditor.component.robot.message.SpecialCtrl;
import com.sw.patroleditor.component.robot.node.GlobalPublishNode;

import java.net.ConnectException;

public interface SWInterface {

    /**
     * 特殊状态控制
     */
    default String specialtrl_SW(String url, String command) throws ConnectException {
        GlobalPublishNode<SpecialCtrl> publishNode =
                new GlobalPublishNode(url, "agv_interface/special_ctrl");

        SpecialCtrl specialCtrl = new SpecialCtrl();
        switch (command) {
            case "shutdown":
                specialCtrl.setShutdown(true); //关机
                break;
            case "reboot":
                specialCtrl.setReboot(true); //重启
                break;
            case "stop":
                specialCtrl.setStop(true);//急停
                break;
            case "release":
                specialCtrl.setRelease(true);//急停释放
                break;
            case "goback":
                specialCtrl.setGoback(true);//一键返航
                break;
            case "charge":
                specialCtrl.setCharge(true);//强制充电
                break;
        }

        publishNode.setMessage(specialCtrl);
        publishNode.publish();

        //读取响应结果
        return publishNode.getResult();
    }

    /**
     * 移动控制
     */
    default String robotCtrl_SW(String url, Move mo) throws ConnectException {
        GlobalPublishNode<RobotCtrl> publishNode =
                new GlobalPublishNode(url, "agv_interface/robot_ctrl");

        RobotCtrl robotCtrl = new RobotCtrl();
        robotCtrl.setRobotMode(1);
        robotCtrl.setPosX(mo.getX());
        robotCtrl.setPosY(mo.getY());
        robotCtrl.setPosZ(mo.getZ());
        robotCtrl.setWorkSpeed(mo.getSpeed());

        publishNode.setMessage(robotCtrl);
        publishNode.publish();

        //读取响应结果
        return publishNode.getResult();
    }

    /**
     * 补光灯控制
     */
    default String openLight_SW(String url, boolean openStatus) throws ConnectException {
        GlobalPublishNode<RobotCtrl> publishNode =
                new GlobalPublishNode(url, "agv_interface/robot_ctrl");

        RobotCtrl robotCtrl = new RobotCtrl();
        robotCtrl.setPtzMode(1);
        robotCtrl.setOpenLight(openStatus);
        publishNode.setMessage(robotCtrl);
        publishNode.publish();

        //读取响应结果
        return publishNode.getResult();
    }

    /**
     * 雨刷控制
     */
    default String openWiper_SW(String url, boolean openStatus) throws ConnectException {
        GlobalPublishNode<RobotCtrl> publishNode =
                new GlobalPublishNode(url, "agv_interface/robot_ctrl");

        RobotCtrl robotCtrl = new RobotCtrl();
        robotCtrl.setPtzMode(1);

        robotCtrl.setOpenWiper(openStatus);
        publishNode.setMessage(robotCtrl);
        publishNode.publish();

        //读取响应结果
        return publishNode.getResult();
    }

    /**
     * 避障雷达控制
     */
    default String openRadar_SW(String url, boolean openStatus) throws ConnectException {
        GlobalPublishNode<RobotCtrl> publishNode =
                new GlobalPublishNode(url, "agv_interface/robot_ctrl");

        RobotCtrl robotCtrl = new RobotCtrl();
        robotCtrl.setPtzMode(1);
        robotCtrl.setOpenRadar(openStatus);
        publishNode.setMessage(robotCtrl);
        publishNode.publish();

        //读取响应结果
        return publishNode.getResult();
    }

    /**
     * 机器人模式切换
     */
    default String modeChange_SW(String url, int modeType) throws ConnectException {
        GlobalPublishNode<SpecialCtrl> publishNode =
                new GlobalPublishNode(url, "agv_interface/special_ctrl");

        SpecialCtrl specialCtrl = new SpecialCtrl();
        switch (modeType) {
            case 3:
                specialCtrl.setCtrlMode(modeType);
                break;
            case 4:
                specialCtrl.setCtrlMode(modeType);
                break;
            default:
                specialCtrl.setCtrlMode(-1);
                break;
        }

        publishNode.setMessage(specialCtrl);
        publishNode.publish();

        //读取响应结果
        return publishNode.getResult();
    }
}

