package com.sw.patroleditor.component.robot.node;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.serializer.SerializeConfig;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.sw.patroleditor.component.tools.HttpJavaTool;

import java.net.ConnectException;

public class GlobalPublishNode<T> {

    private T message;

    private String messageType;

    private String url;

    private String result;

    public GlobalPublishNode(String url, String messageType) {
        super();
        this.url = url;
        this.messageType = "/" + messageType;
    }

    public T getMessage() {
        return message;
    }

    public void setMessage(T message) {
        this.message = message;
    }

    /**
     * 获取节点名称
     */
    public String getDefaultNodeName() {
        return "http-java" + messageType;
    }

    public void publish() throws ConnectException {
        if (url == null || url.isEmpty()) return;

        if (messageType == null || messageType.isEmpty()) return;

        //驼峰改为下划线
        SerializeConfig serializeConfig = new SerializeConfig();
        serializeConfig.propertyNamingStrategy = PropertyNamingStrategy.SnakeCase;
        //取消Null值过滤
        SerializerFeature notNull = SerializerFeature.WriteMapNullValue;

        String json = JSONObject.toJSONString(message, serializeConfig, notNull);
        if (json == null || json.isEmpty()) return;

        System.out.println(json);
        this.result = HttpJavaTool.doPostBody(url + messageType, json);
    }

    public String getResult() {
        return result;
    }

    public void execute() {
    }

    public static void main(String[] args) {
        GlobalPublishNode<String> publishNode =
                new GlobalPublishNode("http://192.168.1.168:9091", "user_msgs/task_param");
        publishNode.setMessage("{\"id\":\"我搜接受对方\"}");
        try {
            publishNode.publish();
        } catch (ConnectException e) {
            e.printStackTrace();
        }
        System.out.println(publishNode.getResult());
    }

}
