package com.sw.patroleditor.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.sw.patroleditor.common.ResultData;
import com.sw.patroleditor.domain.model.*;
import com.sw.patroleditor.exception.BusinessException;
import com.sw.patroleditor.exception.ErrorCode;
import com.sw.patroleditor.service.PTZCtrlService;
import com.sw.patroleditor.util.HkHttpUtils;
import com.sw.patroleditor.util.XmlUtils;

import org.springframework.stereotype.Service;


/**
 * 云台控制接口
 *
 * @author machao
 */
@Service
public class PTZCtrlServiceImpl implements PTZCtrlService {

    HkHttpUtils httpUtils = new HkHttpUtils();

    /**
     * 云台移动
     *
     * @param ptzData
     * @return
     */
    public ResultData continuousChanged(PTZData ptzData) {
        //拼接请求地址
        BodyRequestModel bodyRequestModel = new BodyRequestModel();
        String uri = "/ISAPI/PTZCtrl/channels/" + bodyRequestModel.getChannel() + "/continuous";
        bodyRequestModel.setUri(uri);
        //发送指令
        return sendCMD2Hik(ptzData, bodyRequestModel, PTZData.class);

    }

    /**
     * 改变焦距
     *
     * @param focusData
     * @return
     */
    public ResultData focusChanged(FocusData focusData) {
        BodyRequestModel bodyRequestModel = new BodyRequestModel();
        String uri = "/ISAPI/System/Video/inputs/channels/" + bodyRequestModel.getChannel() + "/focus";
        bodyRequestModel.setUri(uri);
        return sendCMD2Hik(focusData, bodyRequestModel, FocusData.class);

    }


    /**
     * 3D定位
     *
     * @param position3D
     * @return
     */
    public ResultData position3DCtrl(Position3D position3D) {
        BodyRequestModel bodyRequestModel = new BodyRequestModel();
        String uri = "/ISAPI/PTZCtrl/channels/" + bodyRequestModel.getChannel() + "/position3D";
        bodyRequestModel.setUri(uri);
        return sendCMD2Hik(position3D, bodyRequestModel, Position3D.class);
    }


    /**
     * 利用摘要认证并按照ISAPI协议向HIK发送指令
     *
     * @param cmdData
     * @param bodyRequestModel
     * @return
     */
    private ResultData sendCMD2Hik(Object cmdData, BodyRequestModel bodyRequestModel, Class<?>... classT) {
        try {
            String xml = XmlUtils.objectToXml(cmdData, classT);
            bodyRequestModel.setEntity(xml);
            String hkResponse = httpUtils.doBodyPut(bodyRequestModel);
            String jsonString = XmlUtils.xml2Json(hkResponse).get("ResponseStatus").toString();
            HikResponseStatus responseStatus = JSONObject.parseObject(jsonString, HikResponseStatus.class);
            if (responseStatus.getStatusCode() == 1) {
                return ResultData.success();
            }
        } catch (Exception e) {
            throw new BusinessException(ErrorCode.FAIL.getCode(), e.getMessage());
        }
        return ResultData.fail();
    }
}
