package com.sw.patroleditor.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.sw.patroleditor.domain.dto.SystemDictDTO;
import com.sw.patroleditor.domain.dto.UserDTO;
import com.sw.patroleditor.exception.BusinessException;
import com.sw.patroleditor.exception.ErrorCode;
import com.sw.patroleditor.mapper.SystemDictMapper;
import com.sw.patroleditor.mapper.UserMapper;
import com.sw.patroleditor.service.SystemService;
import com.sw.patroleditor.util.DateUtil;
import com.sw.patroleditor.util.MD5Util;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static com.sw.patroleditor.util.DateUtil.DateFormat_yyyyMMddHHmmss;

/**
 * Created by shiwn on 2024/5/29 16:26
 */
@Service
public class SystemServiceImpl implements SystemService {
    @Autowired
    private UserMapper userMapper;
    @Autowired
    private SystemDictMapper systemDictMapper;


    /**
     * @Description: 登录
     * @Param: [account, passWord, request, response]
     * @Author: shiwn
     * @Date: 2021/2/2 9:22
     */
    @Override
    public Map login(String account, String passWord, HttpServletRequest request, HttpServletResponse response) throws Exception {
        //初始化结果集
        Map map = new HashMap();

        try {
            //  用户名、密码验证
            if (StringUtils.isBlank(account)) {
                throw new BusinessException(ErrorCode.ACCOUNT_NULL);
            }
            if (StringUtils.isBlank(passWord)) {
                throw new BusinessException(ErrorCode.PASSWORD_NULL);
            }
            UserDTO user = userMapper.findUserByNameAndPassword(account, MD5Util.encode(passWord));
            if (user == null) {
                throw new BusinessException(ErrorCode.LOGIN_ERROR);
            }
            //  更新用户表的最后登录时间和ip字段
            user.setLoginTime(DateUtil.parseToString(new Date(), DateFormat_yyyyMMddHHmmss))
                    .setLoginIp(request.getRemoteAddr());
            userMapper.updateById(user);
            //  设置cookes
            Cookie cookes = new Cookie("user", user.getAccount());
            cookes.setMaxAge(60 * 60 * 24 * 365);
            response.addCookie(cookes);
            HttpSession session = request.getSession();
            //  将用户信息保存在Session中
            session.setAttribute("loginUser", user.getAccount());
            session.setAttribute("loginUserDTO", user);
            //  设置session过期时间。单位：秒
            //session.setMaxInactiveInterval(30 * 60);
            session.setMaxInactiveInterval(-1);
            //  查询系统字典
            List<SystemDictDTO> listDict = systemDictMapper.selectList(new QueryWrapper<>());

            //  封装返回信息
            map.put("userInfo", user);
            map.put("dictInfo", listDict);
            return map;
        } catch (Exception e) {
            e.printStackTrace();
            throw new BusinessException(ErrorCode.LOGIN_FAIL);
        }
    }
}
